;--------------------------------------------------------------
; read GOES X-ray flux from netCDF data file
;
; Author : Fuminori Tsuchiya (Tohoku-U, Japan)
;
; Date   : 2015-01-23
;
; (in) dir : directory name of input data files
;      file: GOES X-ray data file name (netCDF format; *.nc)
;            Down-loaded from http://www.ngdc.noaa.gov/stp/satellite/goes/dataaccess.html
; (out) time-tag : time record (milliseconds since 1970-01-01 00:00:00.0 UTC)
;       hour     : hour of day (UT)
;       a_flux   : XRS short wavelength channel irradiance (0.05 - 0.4 nm) [W/m^2]
;       b_flux   : XRS long wavelength channel irradiance (0.1-0.8 nm)  [W/m^2]
;--------------------------------------------------------------
;
pro goes_get_xr_ncdf, dir=dir, file=file, time_tag=time_tag,a_flux=a_flux, b_flux=b_flux, hour=hour

  id = ncdf_open(dir+file)

  id_time = ncdf_varid(id,'time_tag')
  id_a    = ncdf_varid(id,'A_FLUX')
  id_b    = ncdf_varid(id,'B_FLUX')

  ncdf_varget, id, id_time, time_tag  ; milliseconds since 1970-01-01 00:00:00.0 UTC 
  ncdf_varget, id, id_a, a_flux       ; XRS short wavelength channel irradiance (0.05 - 0.4 nm) [W/m^2]
  ncdf_varget, id, id_b, b_flux       ; XRS long wavelength channel irradiance (0.1-0.8 nm)  [W/m^2]
  
  ncdf_close, id

  hour = (time_tag / 1000.0 / 3600.0) mod 24.0  
  
end
