;--------------------------------------------------------------
; JJY time code analysis
;
; Author : Fuminori Tsuchiya (Tohoku-U, Japan)
;
; Date   : 2015-01-23
;
; Notice :
;      Success of JJY time code detection strongly depends on S/N of JJY amplitude signal
;      measured. This routine sometimes returns wrong result if the input time code (jjy_code)
;      is created from moderate S/N measurement.
;      Please be careful if receier location is far from transmitters (JJY 40kHz/60kHz)
;
;--------------------------------------------------------------
;
pro lf_search_jjy_code, jjy_code, decode_time

  search_ptn = [1,1,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0]
  decode_time = intarr(7)

  n  = n_elements(jjy_code)
  if (n lt 1200) then begin
    print, 'data length should be 1200'
    decode_time[0] = 0
    return
  endif
  
  ; search start mark
  i_match = -1
  for i=0,599 do begin
    res = 1
    for j=0,19 do begin
      if (jjy_code[i+j] ne search_ptn[j]) then res = 0
    endfor
    if (res eq 1) then begin
      i_match = i+10
      break
    endif
  endfor
  
  if (i_match eq -1) then begin
    print, 'start mark not found'
    decode_time[0] = 0
    return
  endif
  
  ; find time code
  tc = bytarr(60)
  for i=0,59 do begin
    ofs = i_match+i*10
    sum = total(jjy_code[ofs:ofs+9])
    if (sum eq 8) then begin
      tc[i] = 0
    endif else begin
      tc[i] = 1
    endelse
  endfor

  ; find time
  year   = 2000 + 80*tc[41] + 40*tc[42] + 20*tc[43] + 10*tc[44] $
                + 8*tc[45] + 4*tc[46] + 2*tc[47] + tc[48]
  doy    = 200*tc[22] + 100*tc[23] + 80*tc[25] + 40*tc[26] + 20*tc[27] + 10*tc[28] $
         + 8*tc[30] + 4*tc[31] + 2*tc[32] + tc[33]
  hour   = 20*tc[12] + 10*tc[13] $
         + 8*tc[15] + 4*tc[16] + 2*tc[17] + tc[18]
  minute = 40*tc[1] + 20*tc[2] + 10*tc[3] $
                 + 8*tc[5] + 4*tc[6] + 2*tc[7] + tc[8]  
  
  minute = minute - 1
  hour = hour - 9                 ; JST to UT
  if (minute lt 0) then begin
    minute = 59
    hour = hour - 1
  endif
  if (hour lt 0) then begin
    hour = 24 + hour
    doy = doy - 1
  endif
     
  second10 = 600 - i_match
  second = second10 / 10
  subsec = second10 mod 10
  
  ; output
  decode_time[0] = 1
  decode_time[1] = year
  decode_time[2] = doy
  decode_time[3] = hour
  decode_time[4] = minute
  decode_time[5] = second
  decode_time[6] = subsec

end
