;--------------------------------------------------------------
; IDL sample program for plottig GCP and WWLLN data
;
; Author : Fuminori Tsuchiya (Tohoku-U, Japan)
;
; Date   : 2015-01-23
;
;--------------------------------------------------------------
pro main_plot_gcp, src=src, trg=trg, date=date, stime=stime, etime=etime
;
;  (in)  src=[lon, lat] : source position longitude and latitude [degree]
;        trg=[lon, lat] : target position longitude and latitude [degree]
;        date           : date/time to find lightning location with WWLLN (YYYYMMDD)
;        stime          : start time span to find lightning location (hh:nn:ss.sss, UT)
;        etime          : end time span to find lightning location (hh:nn:ss.sss, UT)
;

  if ~keyword_set(src) then src = [130.18,33.47]  ; JJY 60kHz
  if ~keyword_set(trg) then trg = [143.77,43.45]  ; RKB
  if ~keyword_set(date) then date = '20131126'
  if ~keyword_set(stime) then stime = '16:33:00.000'
  if ~keyword_set(etime) then etime = '16:34:00.000'

;  if ~keyword_set(src) then src = [130.18,33.47]  ; JJY 60kHz
;  if ~keyword_set(trg) then trg = [120.12,23.07]  ; TWN
;  if ~keyword_set(date) then date = '20090903'
;  if ~keyword_set(stime) then stime = '16:10:00.000'
;  if ~keyword_set(etime) then etime = '16:20:00.000'

;  if ~keyword_set(src) then src = [115.83,34.63]  ; BPC
;  if ~keyword_set(trg) then trg = [120.12,23.07]  ; TWN
;  if ~keyword_set(date) then date = '20131124'
;  if ~keyword_set(stime) then stime = '15:20:00.000'
;  if ~keyword_set(etime) then etime = '15:30:00.000'

; Calculation of GCP between source to target
  lf_get_gcp, src=src, trg=trg, gcp_lon=lon, gcp_lat=lat

; Find ligntning location with WWLLN data
  dir = 'C:\AVON\LF\wwlln\'
  lf_get_wwlln, dir=dir, date=date, sta_time=stime, end_time=etime, ltime=ltime, llon=llon, llat=llat

;Set window size
  margin = 5.0
  lat_span = max(lat) - min(lat) + margin*2
  lon_span = max(lon) - min(lon) + margin*2
  xsize=400
  ysize=xsize/lon_span*lat_span
  window, 1, xsize=xsize, ysize=ysize

; Plot
  map_set, limit=[min(lat)-margin, min(lon)-margin, max(lat)+margin, max(lon)+margin], /cylindrical, $;londel=15,latdel=15, $
  title='GCP path'
  map_grid, /label
  map_continents,/continents,/hires

  ; Great Circle path
  oplot, lon, lat, color=240

  ; WWLLN
  oplot, llon, llat, psym=1, color=cgColor("Blue")
  
end